Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: src/assembler-irregexp.h

Issue 11600: * Rename to Irregexp throughout.... (Closed) Base URL: http://v8.googlecode.com/svn/branches/experimental/regexp2000/
Patch Set: Created 12 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/assembler.h ('k') | src/assembler-irregexp.cc » ('j') | src/runtime.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/assembler-irregexp.h
===================================================================
--- src/assembler-irregexp.h (revision 825)
+++ src/assembler-irregexp.h (working copy)
@@ -1,14 +1,14 @@
// Copyright 2006-2008 the V8 project authors. All rights reserved.
// A light-weight assembler for the Regexp2000 byte code.
#ifndef V8_ASSEMBLER_RE2K_H_
#define V8_ASSEMBLER_RE2K_H_
namespace v8 { namespace internal {
-class Re2kAssembler {
+class IrregexpAssembler {
public:
// Create an assembler. Instructions and relocation information are emitted
// into a buffer, with the instructions starting from the beginning and the
@@ -23,8 +23,8 @@
// for code generation and assumes its size to be buffer_size. If the buffer
// is too small, a fatal error occurs. No deallocation of the buffer is done
// upon destruction of the assembler.
- explicit Re2kAssembler(Vector<byte>);
- ~Re2kAssembler();
+ explicit IrregexpAssembler(Vector<byte>);
+ ~IrregexpAssembler();
// CP = current position in source.
// BT = backtrack label.
@@ -114,7 +114,7 @@
inline void EmitOrLink(Label* l);
private:
// Don't use this.
- Re2kAssembler() { UNREACHABLE(); }
+ IrregexpAssembler() { UNREACHABLE(); }
// The buffer into which code and relocation info are generated.
Vector<byte> buffer_;
@@ -134,4 +134,4 @@
} } // namespace v8::internal
-#endif // V8_ASSEMBLER_RE2K_H_
+#endif // V8_ASSEMBLER_IRREGEXP_H_
Property changes on: src/assembler-irregexp.h
___________________________________________________________________
Added: svn:mergeinfo
@@ -1,14 +1,14 @@
// Copyright 2006-2008 the V8 project authors. All rights reserved.
-// A light-weight assembler for the Regexp2000 byte code.
+// A light-weight assembler for the Irregexp byte code.
-#ifndef V8_ASSEMBLER_RE2K_H_
-#define V8_ASSEMBLER_RE2K_H_
+#ifndef V8_ASSEMBLER_IRREGEXP_H_
+#define V8_ASSEMBLER_IRREGEXP_H_
namespace v8 { namespace internal {
« no previous file with comments | « src/assembler.h ('k') | src/assembler-irregexp.cc » ('j') | src/runtime.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698